nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Ir

Struct Ir 

#[repr(transparent)]
pub struct Ir(pub u32);
GPT Interrupt Register

Tuple Fields

0: u32

Implementations

Source

impl Ir

pub const fn of1ie(&self) -> bool

See OF3IE

pub const fn set_of1ie(&mut self, val: bool)

See OF3IE

pub const fn of2ie(&self) -> bool

See OF3IE

pub const fn set_of2ie(&mut self, val: bool)

See OF3IE

pub const fn of3ie(&self) -> Of3ie

OF3IE Output Compare 3 Interrupt Enable OF2IE Output Compare 2 Interrupt Enable OF1IE Output Compare 1 Interrupt Enable The OFnIE bit controls the Output Compare Channel n interrupt

pub const fn set_of3ie(&mut self, val: Of3ie)

OF3IE Output Compare 3 Interrupt Enable OF2IE Output Compare 2 Interrupt Enable OF1IE Output Compare 1 Interrupt Enable The OFnIE bit controls the Output Compare Channel n interrupt

pub const fn if1ie(&self) -> bool

See IF2IE

pub const fn set_if1ie(&mut self, val: bool)

See IF2IE

pub const fn if2ie(&self) -> If2ie

IF2IE Input capture 2 Interrupt Enable IF1IE Input capture 1 Interrupt Enable The IFnIE bit controls the IFnIE Input Capture n Interrupt Enable

pub const fn set_if2ie(&mut self, val: If2ie)

IF2IE Input capture 2 Interrupt Enable IF1IE Input capture 1 Interrupt Enable The IFnIE bit controls the IFnIE Input Capture n Interrupt Enable

pub const fn rovie(&self) -> Rovie

Rollover Interrupt Enable. The ROVIE bit controls the Rollover interrupt.

pub const fn set_rovie(&mut self, val: Rovie)

Rollover Interrupt Enable. The ROVIE bit controls the Rollover interrupt.