nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Sr

Struct Sr 

#[repr(transparent)]
pub struct Sr(pub u32);
GPT Status Register

Tuple Fields

0: u32

Implementations

Source

impl Sr

pub const fn of1(&self) -> bool

See OF3

pub const fn set_of1(&mut self, val: bool)

See OF3

pub const fn of2(&self) -> bool

See OF3

pub const fn set_of2(&mut self, val: bool)

See OF3

pub const fn of3(&self) -> Of3

OF3 Output Compare 3 Flag OF2 Output Compare 2 Flag OF1 Output Compare 1 Flag The OFn bit indicates that a compare event has occurred on Output Compare channel n

pub const fn set_of3(&mut self, val: Of3)

OF3 Output Compare 3 Flag OF2 Output Compare 2 Flag OF1 Output Compare 1 Flag The OFn bit indicates that a compare event has occurred on Output Compare channel n

pub const fn if1(&self) -> bool

See IF2

pub const fn set_if1(&mut self, val: bool)

See IF2

pub const fn if2(&self) -> If2

IF2 Input capture 2 Flag IF1 Input capture 1 Flag The IFn bit indicates that a capture event has occurred on Input Capture channel n

pub const fn set_if2(&mut self, val: If2)

IF2 Input capture 2 Flag IF1 Input capture 1 Flag The IFn bit indicates that a capture event has occurred on Input Capture channel n

pub const fn rov(&self) -> Rov

Rollover Flag

pub const fn set_rov(&mut self, val: Rov)

Rollover Flag