#[repr(transparent)]pub struct Sr(pub u32);Expand description
GPT Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Sr
impl Sr
Sourcepub const fn of3(&self) -> Of3
pub const fn of3(&self) -> Of3
OF3 Output Compare 3 Flag OF2 Output Compare 2 Flag OF1 Output Compare 1 Flag The OFn bit indicates that a compare event has occurred on Output Compare channel n
Sourcepub const fn set_of3(&mut self, val: Of3)
pub const fn set_of3(&mut self, val: Of3)
OF3 Output Compare 3 Flag OF2 Output Compare 2 Flag OF1 Output Compare 1 Flag The OFn bit indicates that a compare event has occurred on Output Compare channel n
Sourcepub const fn if2(&self) -> If2
pub const fn if2(&self) -> If2
IF2 Input capture 2 Flag IF1 Input capture 1 Flag The IFn bit indicates that a capture event has occurred on Input Capture channel n